#
# costinit.tcl
# Initialization file for Cost 2
# $Revision: 1.7 $
#

global COST COSTLIB env

if {![info exists COST] || $COST(MAJOR) != 2 || $COST(MINOR) != 1} {
    set errmsg "Cost version mismatch: expected Cost 2.1"
    if [info exists COST] { append errmsg ", got $COST(VERSION)" }
    error $errmsg
}

if [info exists env(COSTLIB)]  {
    set COSTLIB $env(COSTLIB)
} elseif {![info exists COSTLIB]} {
    if [catch {
	set COSTLIB [file join [file dirname [info library]] cost2.1] } ] {
	set COSTLIB /usr/local/lib/cost2.1
    }
}

global __searchPath;	# Search path for 'require' command

if [info exists env(COSTPATH)] {
    set __searchPath [split $env(COSTPATH) ":"]
}
lappend __searchPath $COSTLIB
lappend __searchPath $COSTLIB/utils

#
# Load core utilities:
#
source $COSTLIB/utils/Core.tcl
source $COSTLIB/utils/extmgt.tcl
if {[info commands itcl_info] != ""} {
    source $COSTLIB/utils/EventHandler.itcl
}

### costsh-specific commandline processing:
#
# costsh [-S specfile]
#

proc cost_commandline {} {
    global argv
    set filter 0
    while {[string match "-*" $argv]} {
	switch -- [set option [shift argv]] {
	    -S {
		set specfile [shift argv]
		set filter 1
		break;
	    }
	    -f {
		set filter 1
	    }
	    default {
	       error "unrecognized option $arg"
	   }
	}
    }
    if $filter {loadsgmls stdin}
    if [info exists specfile] {
	global errorInfo
	set status [catch "require $specfile"]
	if {$status == 1} {
	    puts stderr "Error: $errorInfo"
	    error "$specfile initialization failed"
	}
	if { [lsearch [info procs] main] != -1 } {
	    set status [catch main errMsg]
	    if {$status == 1} {
		puts stderr "Error: $errorInfo"
		error "$specfile main routine failed"
	    }
	}
    }
}

